@@ -1,19 +1,5 @@
-//  Copyright (C) 2017 David Faure <faure@kde.org>
-//
-//  This program is free software; you can redistribute it and/or modify
-//  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
-//  (at your option) any later version.
-//
-//  This program is distributed in the hope that it will be useful,
-//  but WITHOUT ANY WARRANTY; without even the7 implied warranty of
-//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-//  GNU General Public License for more details.
-//
-//  You should have received a copy of the GNU General Public License
-//  along with this program; if not, write to the Free Software
-//  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
-//
+//  SPDX-FileCopyrightText: 2017 David Faure <faure@kde.org>
+//  SPDX-License-Identifier: GPL-2.0-or-later
 
 #include <KDBusService>
 #include <QApplication>
@@ -30,6 +16,7 @@
 int main(int argc, char **argv)
 {
     QStringList rawArgs;
+    rawArgs.reserve(argc);
     for (int i = 0; i < argc; ++i) {
         rawArgs << QString::fromLocal8Bit(argv[i]);
     }
@@ -45,7 +32,7 @@ int main(int argc, char **argv)
     QApplication app(argc, argv);
     app.setApplicationName(QStringLiteral("kdialog"));
     app.setOrganizationDomain(QStringLiteral("kde.org"));
-    KLocalizedString::setApplicationDomain("kdialog");
+    KLocalizedString::setApplicationDomain(QByteArrayLiteral("kdialog"));
 
     KDBusService dbusService(KDBusService::Multiple);
 
