@@ -82,7 +82,7 @@ bool Widgets::newPasswordBox(QWidget *parent, const QString &title, const QStrin
     return retcode;
 }
 
-int Widgets::textBox(QWidget *parent, int width, int height, const QString &title, const QString &file)
+bool Widgets::textBox(QWidget *parent, int width, int height, const QString &title, const QString &file)
 {
     QDialog dlg(parent);
     dlg.setWindowTitle(title);
@@ -121,10 +121,10 @@ int Widgets::textBox(QWidget *parent, int width, int height, const QString &titl
 
     Utils::handleXGeometry(&dlg);
     dlg.setWindowTitle(title);
-    return (dlg.exec() == QDialog::Accepted) ? 0 : 1;
+    return dlg.exec() == QDialog::Accepted;
 }
 
-int Widgets::imgBox(QWidget *parent, const QString &title, const QString &file)
+bool Widgets::imgBox(QWidget *parent, const QString &title, const QString &file)
 {
     QDialog dlg(parent);
     dlg.setWindowTitle(title);
@@ -144,10 +144,10 @@ int Widgets::imgBox(QWidget *parent, const QString &title, const QString &file)
 
     label->setPixmap(QPixmap(file));
     Utils::handleXGeometry(&dlg);
-    return (dlg.exec() == QDialog::Accepted) ? 0 : 1;
+    return dlg.exec() == QDialog::Accepted;
 }
 
-int Widgets::imgInputBox(QWidget *parent, const QString &title, const QString &file, const QString &text, QString &result)
+bool Widgets::imgInputBox(QWidget *parent, const QString &title, const QString &file, const QString &text, QString &result)
 {
     QFile f(file);
     if (!f.open(QIODevice::ReadOnly)) {
@@ -188,7 +188,7 @@ int Widgets::imgInputBox(QWidget *parent, const QString &title, const QString &f
     return retcode;
 }
 
-int Widgets::textInputBox(QWidget *parent, int width, int height, const QString &title, const QString &text, const QString &init, QString &result)
+bool Widgets::textInputBox(QWidget *parent, int width, int height, const QString &title, const QString &text, const QString &init, QString &result)
 {
     QDialog dlg(parent);
     dlg.setWindowTitle(title);
@@ -216,7 +216,7 @@ int Widgets::textInputBox(QWidget *parent, int width, int height, const QString
     dlg.setWindowTitle(title);
     const int returnDialogCode = dlg.exec();
     result = edit->toPlainText();
-    return returnDialogCode == QDialog::Accepted ? 0 : 1;
+    return returnDialogCode == QDialog::Accepted;
 }
 
 bool Widgets::comboBox(QWidget *parent, const QString &title, const QString &text, const QStringList &args, const QString &defaultEntry, QString &result)
